##  Calculate the 6R Classification
Use calculations to determine an application’s 6R classification based on values from other fact sheet fields. To streamline the 6R classification process, you can set up a custom calculation. SAP LeanIX will then give you automated recommendations to help you choose the most suitable approach for each application.
Learn more about custom calculations in [Custom Calculations](https://help.sap.com/docs/leanix/ea/calculations?locale=en-US&state=PRODUCTION&version=CLOUD#loio275919c67a441014a04fa34f480310eb__custom_calculations).
